#ifdef WIN32
#include <windows.h>
#endif

#include <gl\gl.h>
#include <gl\glu.h>
#include <string>
#include "functions.h"
#include "skeletonElements.h"
#include "skeleton.h"

Color* colors[5];

Skeleton::Skeleton(Color* bodyC){


  colors[0] = new Color(1.0, 0.0, 0.0);
  colors[1] = bodyC;//color for the torso
  colors[2] = new Color(0.8, 0.8, 0.0);
  colors[3] = new Color(0.2, 0.0, 0.5);
  colors[4] = new Color(0.1, 0.4, 0.1);


  head = new SkeletonLink((string)"head", (GLfloat)0.5, (GLfloat)0.5, 0, colors[2]);
  torso = new SkeletonLink((string)"torso", (GLfloat)1.0, (GLfloat)3.0, 1, colors[1]);
  lupperArm = new SkeletonLink((string)"lupperArm", (GLfloat)0.1, (GLfloat)1.5, 0, colors[3]);
  llowerArm = new SkeletonLink((string)"llowerArm", (GLfloat)0.1, (GLfloat)1.5, 0, colors[4]);
  rupperArm = new SkeletonLink((string)"rupperArm", (GLfloat)0.1, (GLfloat)1.5, 0, colors[3]);
  rlowerArm = new SkeletonLink((string)"rlowerArm", (GLfloat)0.1, (GLfloat)1.5, 0, colors[4]);
  lupperLeg = new SkeletonLink((string)"lupperLeg", (GLfloat)0.2, (GLfloat)1.4, 0, colors[3]);
  rupperLeg = new SkeletonLink((string)"rupperLeg", (GLfloat)0.2, (GLfloat)1.4, 0, colors[3]);
  llowerLeg = new SkeletonLink((string)"llowerLeg", (GLfloat)0.2, (GLfloat)1.5, 0, colors[4]);
  rlowerLeg = new SkeletonLink((string)"rlowerLeg", (GLfloat)0.2, (GLfloat)1.5, 0, colors[4]);

  lshoulderRotUD = new SkeletonJoints((string)"lshoulderRotUD", 90.0, -90.0, 120.0);
  lshoulderRotLR = new SkeletonJoints((string)"lshoulderRotLR", 0.0, -30.0, 90.0);
  rshoulderRotUD = new SkeletonJoints((string)"rshoulderRotUD", 90.0, -90.0, 120.0);
  rshoulderRotLR = new SkeletonJoints((string)"rshoulderRotLR", 0.0, -90.0, 30.0);
  lelbowRotUD = new SkeletonJoints((string)"lelbowRotUD", -15.0, -150.0, -5.0);
  relbowRotUD = new SkeletonJoints((string)"relbowRotUD", -15.0, -150.0, -5.0);
  lhipRotUD = new SkeletonJoints((string)"lhipRotUD", 90.0, -30.0, 120.0);
  rhipRotUD = new SkeletonJoints((string)"rhipRotUD", 90.0, -30.0, 120.0);
  lkneeRotUD = new SkeletonJoints((string)"lkneeRotUD", 0.0, 0.0, 90.0);
  rkneeRotUD = new SkeletonJoints((string)"rkneeRotUD", 0.0, 0.0, 90.0);

  lupperArm->joints.push_back(lshoulderRotUD);
  lupperArm->joints.push_back(lshoulderRotLR);
  llowerArm->joints.push_back(lelbowRotUD);
  rupperArm->joints.push_back(rshoulderRotUD);
  rupperArm->joints.push_back(rshoulderRotLR);
  rlowerArm->joints.push_back(relbowRotUD);

  lupperLeg->joints.push_back(lhipRotUD);
  llowerLeg->joints.push_back(lkneeRotUD);
  rupperLeg->joints.push_back(rhipRotUD);
  rlowerLeg->joints.push_back(rkneeRotUD);
}

void Skeleton::SkeletonDOF(){
  //postaviti ogranicenja
}

void Skeleton::DrawSkeleton(){

  //skelet->SkeletonDOF();
  GLUquadricObj *obj = gluNewQuadric();
  glPushMatrix();
  glTranslatef(0.0f,3.5f, 0.0f);
{
  //the torso of the robot
  glColor3f(torso->linkColor->red, torso->linkColor->green, torso->linkColor->blue);
  DrawQuad(torso->width, torso->length, torso->width);
}

{
  //the head of the robot
  glPushMatrix();
  glColor3f(head->linkColor->red, head->linkColor->green, head->linkColor->blue);
  glTranslatef(0.0, torso->length + head->width, -head->width);
  gluSphere(obj, head->width, 10, 10);
  glColor3f(0.0, 0.0, 1.0);//right eye
  glTranslatef(-0.2, 0.0, 0.4);
  gluSphere(obj, 0.07, 10, 10);
  glTranslatef(0.4, 0.0, 0.0);//left eye
  gluSphere(obj, 0.07, 10, 10);
  glPopMatrix();
}

{
  //the right arm of the robot
  glPushMatrix();
  glColor3f(rupperArm->linkColor->red, rupperArm->linkColor->green, lupperArm->linkColor->blue);
  glTranslatef(-1.2, 2.9, -0.0);

  gluSphere(obj, 0.2, 10, 10);
  rupperArm->doRotation();

  gluSphere(obj, 0.2, 10, 10);
  gluCylinder(obj, rupperArm->width, rupperArm->width, rupperArm->length, 10, 10);

  glTranslatef(0.0, 0.0, 1.5);//because of the previous rotation y is now z
  gluSphere(obj, 0.2, 10, 10);

  glColor3f(rlowerArm->linkColor->red, llowerArm->linkColor->green, llowerArm->linkColor->blue);
  rlowerArm->doRotation();
  gluCylinder(obj, rlowerArm->width, rlowerArm->width, rlowerArm->length, 10, 10);
  glColor3f(0.5, 0.5, 0.5);
  glTranslatef(0.0, 0.0, 1.5);//hand sphere
  gluSphere(obj, 0.2, 10, 10);
  glPopMatrix();
}

{
  //the left arm of the robot
  glPushMatrix();
  glColor3f(lupperArm->linkColor->red, lupperArm->linkColor->green, lupperArm->linkColor->blue);
  glTranslatef(1.2, 2.9, -0.0);

  lupperArm->doRotation();

  gluSphere(obj, 0.2, 10, 10);
  gluCylinder(obj, lupperArm->width, lupperArm->width, lupperArm->length, 10, 10);

  glTranslatef(0.0, 0.0, 1.5);//because of the previous rotation y is now z
  gluSphere(obj, 0.2, 10, 10);

  glColor3f(llowerArm->linkColor->red, llowerArm->linkColor->green, llowerArm->linkColor->blue);
  llowerArm->doRotation();
  gluCylinder(obj, llowerArm->width, llowerArm->width, llowerArm->length, 10, 10);
  glColor3f(0.5, 0.5, 0.5);
  glTranslatef(0.0, 0.0, 1.5);//hand sphere
  gluSphere(obj, 0.2, 10, 10);
  glPopMatrix();
}

{
  //the left leg of the robot
  glPushMatrix();
  glColor3f(lupperLeg->linkColor->red, lupperLeg->linkColor->green, lupperLeg->linkColor->blue);
  glTranslatef(0.7, 0.0, -0.5);
  lupperLeg->doRotation();

  gluSphere(obj, 0.3, 10, 10);
  gluCylinder(obj, lupperLeg->width, lupperLeg->width, lupperLeg->length, 10, 10);

  glTranslatef(0.0, 0.0, 1.4);//because of the previous rotation y is now z
  gluSphere(obj, 0.3, 10, 10);

  glColor3f(llowerLeg->linkColor->red, llowerLeg->linkColor->green, llowerLeg->linkColor->blue);
  llowerLeg->doRotation();
  gluCylinder(obj, llowerLeg->width, llowerLeg->width, llowerLeg->length, 10, 10);
  //glPopMatrix();
}

{
  //the left foot of the robot
  //glPushMatrix();
  glColor3f(0.9, 0.0, 0.5);
  glTranslatef(0.0, -0.2, 1.5);
  glRotatef(-180.0, 1.0, 0.0, 0.0);

  glColor3f(0.2f, 0.1f, 0.9f);
  DrawQuad(0.2, -1.0, 0.2);

  glPopMatrix();
}

{
  //the right leg of the robot
  glPushMatrix();
  glColor3f(rupperLeg->linkColor->red, rupperLeg->linkColor->green, rupperLeg->linkColor->blue);
  glTranslatef(-0.7, 0.0, -0.5);
  rupperLeg->doRotation();

  gluSphere(obj, 0.3, 10, 10);
  gluCylinder(obj, rupperLeg->width, rupperLeg->width, rupperLeg->length, 10, 10);

  glTranslatef(0.0, 0.0, 1.4);//because of the previous rotation y is now z
  gluSphere(obj, 0.3, 10, 10);

  glColor3f(llowerLeg->linkColor->red, llowerLeg->linkColor->green, llowerLeg->linkColor->blue);
  rlowerLeg->doRotation();
  gluCylinder(obj, rlowerLeg->width, rlowerLeg->width, rlowerLeg->length, 10, 10);
  //glPopMatrix();
}

{
  //the right foot of the robot
  //glPushMatrix();
  glColor3f(0.9, 0.0, 0.5);
  glTranslatef(0.0, -0.2, 1.5);
  glRotatef(-180.0, 1.0, 0.0, 0.0);

  glColor3f(0.2f, 0.1f, 0.9f);
  DrawQuad(0.2, -1.0, 0.2);

  glPopMatrix();
}

  glPopMatrix();

}
